@@ -1,4 +1,5 @@
 import contextlib
+import itertools
 import os
 import tempfile
 import unittest
@@ -11,7 +12,6 @@ from iker.common.utils.shutils import listfile
 from iker.common.utils.testutils import norm_path
 
 from plexus.common.utils.s3utils import *
-from plexus.common.utils.s3utils import s3_estimate_archive_ranged_requests
 from plexus_tests import resources_directory
 
 
@@ -493,22 +493,20 @@ class S3UtilsTest(unittest.TestCase):
                 client,
                 "s3://dummy-bucket/s3utils_archive/archive.uncompressed.zip",
                 members,
-                member_header_overhead=0,
                 central_directory_overhead=0,
             )
 
-            self.assertEqual(archive_size - ranged_total_size, 2470)
+            self.assertEqual(archive_size - ranged_total_size, 1190)
             self.assertEqual(len(missing_members), 0)
 
             ranged_total_size, archive_size, missing_members = s3_estimate_archive_ranged_requests(
                 client,
                 "s3://dummy-bucket/s3utils_archive/archive.compressed.zip",
                 members,
-                member_header_overhead=0,
                 central_directory_overhead=0,
             )
 
-            self.assertEqual(archive_size - ranged_total_size, 2470)
+            self.assertEqual(archive_size - ranged_total_size, 1190)
             self.assertEqual(len(missing_members), 0)
 
     def test_s3_open_archive_member(self):
@@ -528,26 +526,17 @@ class S3UtilsTest(unittest.TestCase):
 
             members = [os.path.relpath(file_path, local_root) for file_path in listfile(local_root)]
 
-            for member in members:
-                with (
-                    open(os.path.join(local_root, member), "r") as local_fh,
-                    s3_open_archive_member(
-                        client,
-                        "s3://dummy-bucket/s3utils_archive/archive.uncompressed.zip",
-                        member,
-                    ) as s3_fh,
-                ):
-                    self.assertEqual(local_fh.read(), s3_fh.read())
-
-                with (
-                    open(os.path.join(local_root, member), "r") as local_fh,
-                    s3_open_archive_member(
-                        client,
-                        "s3://dummy-bucket/s3utils_archive/archive.compressed.zip",
-                        member,
-                    ) as s3_fh,
-                ):
-                    self.assertEqual(local_fh.read(), s3_fh.read())
+            for archive_url, mode in itertools.product(
+                ["s3://dummy-bucket/s3utils_archive/archive.uncompressed.zip",
+                 "s3://dummy-bucket/s3utils_archive/archive.compressed.zip"],
+                ["r", "rb"],
+            ):
+                for member in members:
+                    with (
+                        open(os.path.join(local_root, member), mode) as local_fh,
+                        s3_open_archive_member(client, archive_url, member, mode) as s3_fh,
+                    ):
+                        self.assertEqual(local_fh.read(), s3_fh.read())
 
     def test_s3_open_archive_members(self):
         with (
@@ -566,86 +555,21 @@ class S3UtilsTest(unittest.TestCase):
 
             members = [os.path.relpath(file_path, local_root) for file_path in listfile(local_root)]
 
-            for member, opener in s3_open_archive_members(
-                client,
-                "s3://dummy-bucket/s3utils_archive/archive.uncompressed.zip",
-                members,
-                threshold=1.0,
-                member_header_overhead=0,
-                central_directory_overhead=0,
+            for archive_url, mode, threshold, use_chunked_reads in itertools.product(
+                ["s3://dummy-bucket/s3utils_archive/archive.uncompressed.zip",
+                 "s3://dummy-bucket/s3utils_archive/archive.compressed.zip"],
+                ["r", "rb"],
+                [1.0, 0.0],
+                [False, True],
             ):
-                with open(os.path.join(local_root, member), "r") as local_fh, opener() as s3_fh:
-                    self.assertEqual(local_fh.read(), s3_fh.read())
-
-            for member, opener in s3_open_archive_members(
-                client,
-                "s3://dummy-bucket/s3utils_archive/archive.compressed.zip",
-                members,
-                threshold=1.0,
-                member_header_overhead=0,
-                central_directory_overhead=0,
-            ):
-                with open(os.path.join(local_root, member), "r") as local_fh, opener() as s3_fh:
-                    self.assertEqual(local_fh.read(), s3_fh.read())
-
-            for member, opener in s3_open_archive_members(
-                client,
-                "s3://dummy-bucket/s3utils_archive/archive.uncompressed.zip",
-                members,
-                threshold=0.0,
-            ):
-                with open(os.path.join(local_root, member), "r") as local_fh, opener() as s3_fh:
-                    self.assertEqual(local_fh.read(), s3_fh.read())
-
-            for member, opener in s3_open_archive_members(
-                client,
-                "s3://dummy-bucket/s3utils_archive/archive.compressed.zip",
-                members,
-                threshold=0.0,
-            ):
-                with open(os.path.join(local_root, member), "r") as local_fh, opener() as s3_fh:
-                    self.assertEqual(local_fh.read(), s3_fh.read())
-
-            for member, opener in s3_open_archive_members(
-                client,
-                "s3://dummy-bucket/s3utils_archive/archive.uncompressed.zip",
-                members,
-                "rb",
-                threshold=1.0,
-                member_header_overhead=0,
-                central_directory_overhead=0,
-            ):
-                with open(os.path.join(local_root, member), "rb") as local_fh, opener() as s3_fh:
-                    self.assertEqual(local_fh.read(), s3_fh.read())
-
-            for member, opener in s3_open_archive_members(
-                client,
-                "s3://dummy-bucket/s3utils_archive/archive.compressed.zip",
-                members,
-                "rb",
-                threshold=1.0,
-                member_header_overhead=0,
-                central_directory_overhead=0,
-            ):
-                with open(os.path.join(local_root, member), "rb") as local_fh, opener() as s3_fh:
-                    self.assertEqual(local_fh.read(), s3_fh.read())
-
-            for member, opener in s3_open_archive_members(
-                client,
-                "s3://dummy-bucket/s3utils_archive/archive.uncompressed.zip",
-                members,
-                "rb",
-                threshold=0.0,
-            ):
-                with open(os.path.join(local_root, member), "rb") as local_fh, opener() as s3_fh:
-                    self.assertEqual(local_fh.read(), s3_fh.read())
-
-            for member, opener in s3_open_archive_members(
-                client,
-                "s3://dummy-bucket/s3utils_archive/archive.compressed.zip",
-                members,
-                "rb",
-                threshold=0.0,
-            ):
-                with open(os.path.join(local_root, member), "rb") as local_fh, opener() as s3_fh:
-                    self.assertEqual(local_fh.read(), s3_fh.read())
+                for member, opener in s3_open_archive_members(
+                    client,
+                    archive_url,
+                    members,
+                    mode,
+                    threshold=threshold,
+                    central_directory_overhead=0,
+                    use_chunked_reads=use_chunked_reads,
+                ):
+                    with open(os.path.join(local_root, member), mode) as local_fh, opener() as s3_fh:
+                        self.assertEqual(local_fh.read(), s3_fh.read())
