@@ -7,10 +7,10 @@ from iker.common.utils.dtutils import dt_parse_iso
 from plexus.common.utils.strutils import BagName, UserEmail, UserName, VehicleName
 from plexus.common.utils.strutils import colon_tag_parser, colon_tag_pattern, slash_tag_parser, slash_tag_pattern
 from plexus.common.utils.strutils import dot_case_parser, dot_case_pattern
+from plexus.common.utils.strutils import email_address_parser, email_address_pattern, semver_parser, semver_pattern
 from plexus.common.utils.strutils import hex_string_parser, hex_string_pattern
 from plexus.common.utils.strutils import kebab_case_parser, kebab_case_pattern
 from plexus.common.utils.strutils import parse_bag_name, parse_user_email, parse_user_name, parse_vehicle_name
-from plexus.common.utils.strutils import semver_parser, semver_pattern
 from plexus.common.utils.strutils import snake_case_parser, snake_case_pattern
 from plexus.common.utils.strutils import strict_abspath_parser, strict_abspath_pattern
 from plexus.common.utils.strutils import strict_relpath_parser, strict_relpath_pattern
@@ -377,6 +377,43 @@ class StrUtilsTest(unittest.TestCase):
         with self.assertRaises(pp.ParseException):
             strict_abspath_parser.parse_string(data, parse_all=True)
 
+    data_email_address_pattern = [
+        ("someone@dummy.com",),
+        ("some.one@dummy.com",),
+        ("some.1@dummy.com",),
+        ("some-one@dummy.com",),
+        ("someone-@dummy.com",),
+        ("someone@dummy.company.com",),
+        ("some.one@dummy-company.com",),
+        ("some.1@dummy.company-company.com",),
+        ("some_one@dummy-1st-company.co-ltd.com",),
+    ]
+
+    @ddt.idata(data_email_address_pattern)
+    @ddt.unpack
+    def test_email_address_pattern(self, data):
+        self.assertIsNotNone(email_address_pattern.match(data))
+        self.assertIsNotNone(email_address_parser.parse_string(data, parse_all=True))
+
+    data_email_address_pattern__bad_cases = [
+        ("",),
+        ("some.one",),
+        ("@dummy.com",),
+        ("someone@dummy",),
+        ("someone@dummy.methionylthreonylthreonylglutaminylarginyltyrosylglutamylserylleucine",),
+        ("someone+one@dummy.com",),
+        ("someone.@dummy.com",),
+        ("someone@.dummy.com",),
+        ("someone@dummy-.com",),
+    ]
+
+    @ddt.idata(data_email_address_pattern__bad_cases)
+    @ddt.unpack
+    def test_email_address_pattern__bad_cases(self, data):
+        self.assertIsNone(email_address_pattern.match(data))
+        with self.assertRaises(pp.ParseException):
+            email_address_parser.parse_string(data, parse_all=True)
+
     data_semver_pattern = [
         ("0.0.0",),
         ("1.2.3",),
